@@ -7,7 +7,7 @@ use OpenGL::Sandbox qw/ glGetString GL_VERSION /;
 use X11::GLX::DWIM;
 
 # ABSTRACT: Create OpenGL context with X11::GLX::DWIM
-our $VERSION = '0.110'; # VERSION
+our $VERSION = '0.120'; # VERSION
 
 our %instances;
 sub new {
@@ -15,6 +15,13 @@ sub new {
 	my %opts= ref $_[0] eq 'HASH'? %{$_[0]} : @_;
 	my $visible= $opts{visible} // 1;
 	my $glx= X11::GLX::DWIM->new();
+	if ($opts{fullscreen}) {
+		# TODO: X11::Xlib doesn't have access to the modern concept of screen yet, only the
+		#  idea of a screen that covers all physical monitors.  Need to add support for that.
+		my $screen= $glx->screen;
+		$opts{width}= $screen->width;
+		$opts{height}= $screen->height;
+	}
 	# Target is lazy.  Make sure GL context fully initialized before return.
 	if ($visible) {
 		$glx->target({ window => {
@@ -66,7 +73,7 @@ OpenGL::Sandbox::ContextShim::GLX - Create OpenGL context with X11::GLX::DWIM
 
 =head1 VERSION
 
-version 0.110
+version 0.120
 
 =head1 DESCRIPTION
 
