@@ -12,7 +12,7 @@ sub mmap { OpenGL::Sandbox::MMap->new(shift) }
 our @CARP_NOT= ( 'OpenGL::Sandbox' );
 
 # ABSTRACT: Resource manager for OpenGL prototyping
-our $VERSION = '0.110'; # VERSION
+our $VERSION = '0.120'; # VERSION
 
 
 our $_default_instance;
@@ -393,7 +393,7 @@ OpenGL::Sandbox::ResMan - Resource manager for OpenGL prototyping
 
 =head1 VERSION
 
-version 0.110
+version 0.120
 
 =head1 SYNOPSIS
 
@@ -686,7 +686,7 @@ this name in L</buffer_config>.  This dies if C<$name> was already created.
   my $vertex_array= $res->vao( $name );          # handy alias
   my $vertex_array= $res->new_vao( $name, %options );
 
-Return an existing or configured L<OpenGL::Sandbox::VertexArray|Vertex Array>.
+Return an existing or configured L<Vertex Array|OpenGL::Sandbox::VertexArray>.
 The configurations may reference Buffer objects by name, and these will be translated
 to the actual perl object with calls to L</buffer> before constructing the vertex array.
 
